@@ -8,16 +8,8 @@
 
 package Gearman::XS::Job;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.6_01';
-
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Job - Perl job for gearman using libgearman
@@ -37,6 +29,11 @@ Get the workload for a job.
 
 Get job handle.
 
+=head2 $job->status($numerator, $denominator)
+
+Send status information for a running job. Returns a standard gearman return
+value.
+
 =head2 $job->function_name()
 
 Get the function name associated with a job.
@@ -45,28 +42,10 @@ Get the function name associated with a job.
 
 Get the unique ID associated with a job.
 
-=head2 $job->send_status($numerator, $denominator)
-
-Send status information for a running job. Returns a standard gearman return
-value.
-
-=head2 $job->send_data($data)
+=head2 $job->data($data)
 
 Send data for a running job. Returns a standard gearman return value.
 
-=head2 $job->send_fail()
-
-Send fail status for a job. Returns a standard gearman return value.
-
-=head2 $job->send_complete($result)
-
-Send result and complete status for a job. Returns a standard gearman return
-value.
-
-=head2 $job->send_warning($warning)
-
-Send warning for a running job. Returns a standard gearman return value.
-
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
@@ -83,13 +62,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
+=head1 AUTHORS
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
\ No newline at end of file
+=cut
+
+1;
\ No newline at end of file
