@@ -8,16 +8,8 @@
 
 package Gearman::XS::Task;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.6_01';
-
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Task - Perl task for gearman using libgearman
@@ -41,7 +33,7 @@ Get data being returned for a task.
 
 Get data size being returned for a task.
 
-=head2 $task->function_name()
+=head2 $task->function()
 
 Get function name associated with a task.
 
@@ -53,20 +45,6 @@ Get the numerator of percentage complete for a task.
 
 Get the denominator of percentage complete for a task.
 
-=head2 $task->unique()
-
-Get unique identifier for a task.
-
-=head2 $task->is_known()
-
-Get status on whether a task is known or not. Returns 1 if known, empty string
-if not.
-
-=head2 $task->is_running()
-
-Get status on whether a task is running or not. Returns 1 if running, empty
-string if not.
-
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
@@ -83,13 +61,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
+=head1 AUTHORS
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
\ No newline at end of file
+=cut
+
+1;
\ No newline at end of file
